CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
52 lines
2.8 KiB
Plaintext
52 lines
2.8 KiB
Plaintext
// RUN: %clang_cc1 -std=c++11 -fsyntax-only -verify %s
|
|
// RUN: %clang_cc1 -std=c++11 -fsyntax-only -fcuda-is-device -verify %s
|
|
|
|
__attribute__((device)) void device_fn() {}
|
|
__attribute__((host, device)) void hd_fn() {}
|
|
|
|
__attribute__((device)) void device_attr() {
|
|
([]() __attribute__((device)) { device_fn(); })();
|
|
// expected-warning@-1 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([] __attribute__((device)) () { device_fn(); })();
|
|
([] __attribute__((device)) { device_fn(); })();
|
|
|
|
([&]() __attribute__((device)){ device_fn(); })();
|
|
// expected-warning@-1 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([&] __attribute__((device)) () { device_fn(); })();
|
|
([&] __attribute__((device)) { device_fn(); })();
|
|
|
|
([&](int) __attribute__((device)){ device_fn(); })(0);
|
|
// expected-warning@-1 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([&] __attribute__((device)) (int) { device_fn(); })(0);
|
|
|
|
// test that noinline can appear anywhere.
|
|
([&] __attribute__((device)) __noinline__ () { device_fn(); })();
|
|
([&] __noinline__ __attribute__((device)) () { device_fn(); })();
|
|
}
|
|
|
|
__attribute__((host)) __attribute__((device)) void host_device_attrs() {
|
|
([]() __attribute__((host)) __attribute__((device)){ hd_fn(); })();
|
|
// expected-warning@-1 {{nvcc does not allow '__host__' to appear after the parameter list in lambdas}}
|
|
// expected-warning@-2 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([] __attribute__((host)) __attribute__((device)) () { hd_fn(); })();
|
|
([] __attribute__((host)) __attribute__((device)) { hd_fn(); })();
|
|
|
|
([&]() __attribute__((host)) __attribute__((device)){ hd_fn(); })();
|
|
// expected-warning@-1 {{nvcc does not allow '__host__' to appear after the parameter list in lambdas}}
|
|
// expected-warning@-2 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([&] __attribute__((host)) __attribute__((device)) () { hd_fn(); })();
|
|
([&] __attribute__((host)) __attribute__((device)) { hd_fn(); })();
|
|
|
|
([&](int) __attribute__((host)) __attribute__((device)){ hd_fn(); })(0);
|
|
// expected-warning@-1 {{nvcc does not allow '__host__' to appear after the parameter list in lambdas}}
|
|
// expected-warning@-2 {{nvcc does not allow '__device__' to appear after the parameter list in lambdas}}
|
|
([&] __attribute__((host)) __attribute__((device)) (int) { hd_fn(); })(0);
|
|
|
|
// test that noinline can also appear anywhere.
|
|
([] __attribute__((host)) __attribute__((device)) () { hd_fn(); })();
|
|
([] __attribute__((host)) __noinline__ __attribute__((device)) () { hd_fn(); })();
|
|
([] __attribute__((host)) __attribute__((device)) __noinline__ () { hd_fn(); })();
|
|
}
|
|
|
|
// TODO: Add tests for __attribute__((global)) once we support global lambdas.
|